const state = {
    customers: [],
    filtered: [],
    selectedCustomer: null
}

const getters = {
    getCustomers(state) {
        return state.filtered.length === 0 ? state.customers : state.filtered
    },
    hasSelectedCustomer(state) {
        return !!state.selectedCustomer
    }
}

const mutations = {
    pushCustomers(state, payload) {
        state.customers = [...payload.customers]
    },
    selectCustomer(state, payload) {
        state.selectedCustomer = payload.customer
    },
    applyCustomersFilter(state, payload) {
        state.filtered = payload
    }
}

const actions = {
    fetchCustomers({ commit, dispatch }) {
        return new Promise((resolve, reject) => {
            let customer = new openerp.web.Model('res.partner')
            customer.query(['name', 'display_name', 'image_medium']).filter([['customer', '=', true], ['is_company', '=', false], ['active', '=', true]]).all().then(response => {
                commit('pushCustomers', {
                    customers: response
                })
                
                dispatch('loaded', {
                    module: 'customers'
                })

                resolve()
            }).fail(error => {
                console.log(error)
                reject(error)
            })
        })
    },
    selectCustomer({ commit }, payload) {
        commit('selectCustomer', payload)
    },
    filterCustomers({ commit }, payload) {
        commit('applyCustomersFilter', payload)
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}
